==> ejc-jlprogress-impl-3.0.0-20241111.102036-407-sources.jar: com/ejianc/business/jlprogress/factory/vo/FactJigaiDetailVO.java <==
package com.ejianc.business.jlprogress.factory.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 制造厂-技改项目进度明细表
 *
 * @author generator
 *
 */
public class FactJigaiDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long jigaiId; // 主表ID
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM",
            timezone = "GMT+8"
    )
    private Date detailMonth; // 填报月份
    private String projectMemo; // 项目简介
    private BigDecimal selfMny; // 自产金额
    private BigDecimal outMny; // 外购金额
    private BigDecimal preNum; // 预计投产数量
    private String manager; // 项目负责人
    private String progressDesc; // 进度说明
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date preFinishDate; // 预计完工时间
    private String memo; // 备注
    private Long projectId; // 项目ID
    private String projectCode; // 项目code
    private String projectName; // 项目名称
    private Long sourceId; // 来源ID
    private String beginEndDate;
    private String errorMsg; // 导入错误信息
    private String reportMonth;

    public String getReportMonth() {
        return reportMonth;
    }

    public void setReportMonth(String reportMonth) {
        this.reportMonth = reportMonth;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public Long getJigaiId() {
        return jigaiId;
    }

    public void setJigaiId(Long jigaiId) {
        this.jigaiId = jigaiId;
    }

    public Date getDetailMonth() {
        return detailMonth;
    }

    public void setDetailMonth(Date detailMonth) {
        this.detailMonth = detailMonth;
    }

    public String getProjectMemo() {
        return projectMemo;
    }

    public void setProjectMemo(String projectMemo) {
        this.projectMemo = projectMemo;
    }
    public BigDecimal getSelfMny() {
        return selfMny;
    }

    public void setSelfMny(BigDecimal selfMny) {
        this.selfMny = selfMny;
    }
    public BigDecimal getOutMny() {
        return outMny;
    }

    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }
    public BigDecimal getPreNum() {
        return preNum;
    }

    public void setPreNum(BigDecimal preNum) {
        this.preNum = preNum;
    }
    public String getManager() {
        return manager;
    }

    public void setManager(String manager) {
        this.manager = manager;
    }
    public String getProgressDesc() {
        return progressDesc;
    }

    public void setProgressDesc(String progressDesc) {
        this.progressDesc = progressDesc;
    }
    public Date getPreFinishDate() {
        return preFinishDate;
    }

    public void setPreFinishDate(Date preFinishDate) {
        this.preFinishDate = preFinishDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getBeginEndDate() {
        return beginEndDate;
    }

    public void setBeginEndDate(String beginEndDate) {
        this.beginEndDate = beginEndDate;
    }
}

==> ejc-jlprogress-impl-3.0.0-20241127.095459-466-sources.jar: com/ejianc/business/jlprogress/factory/vo/FactJigaiDetailVO.java <==
package com.ejianc.business.jlprogress.factory.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 制造厂-技改项目进度明细表
 *
 * @author generator
 *
 */
public class FactJigaiDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long jigaiId; // 主表ID
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM",
            timezone = "GMT+8"
    )
    private Date detailMonth; // 填报月份
    private String projectMemo; // 项目简介
    private BigDecimal selfMny; // 自产金额
    private BigDecimal outMny; // 外购金额
    private String preNum; // 预计投产数量
    private String manager; // 项目负责人
    private String progressDesc; // 进度说明
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date preFinishDate; // 预计完工时间
    private String memo; // 备注
    private Long projectId; // 项目ID
    private String projectCode; // 项目code
    private String projectName; // 项目名称
    private Long sourceId; // 来源ID
    private String beginEndDate;
    private String errorMsg; // 导入错误信息
    private String reportMonth;
    private Integer factoryCategory; // 生产厂
    private String factoryName; // 生产厂名称

    private  String state;

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getFactoryName() {
        return factoryName;
    }

    public void setFactoryName(String factoryName) {
        this.factoryName = factoryName;
    }

    public String getReportMonth() {
        return reportMonth;
    }

    public void setReportMonth(String reportMonth) {
        this.reportMonth = reportMonth;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public Long getJigaiId() {
        return jigaiId;
    }

    public void setJigaiId(Long jigaiId) {
        this.jigaiId = jigaiId;
    }

    public Date getDetailMonth() {
        return detailMonth;
    }

    public void setDetailMonth(Date detailMonth) {
        this.detailMonth = detailMonth;
    }

    public String getProjectMemo() {
        return projectMemo;
    }

    public void setProjectMemo(String projectMemo) {
        this.projectMemo = projectMemo;
    }
    public BigDecimal getSelfMny() {
        return selfMny;
    }

    public void setSelfMny(BigDecimal selfMny) {
        this.selfMny = selfMny;
    }
    public BigDecimal getOutMny() {
        return outMny;
    }

    public void setOutMny(BigDecimal outMny) {
        this.outMny = outMny;
    }
    public String getPreNum() {
        return preNum;
    }

    public void setPreNum(String preNum) {
        this.preNum = preNum;
    }
    public String getManager() {
        return manager;
    }

    public void setManager(String manager) {
        this.manager = manager;
    }
    public String getProgressDesc() {
        return progressDesc;
    }

    public void setProgressDesc(String progressDesc) {
        this.progressDesc = progressDesc;
    }
    public Date getPreFinishDate() {
        return preFinishDate;
    }

    public void setPreFinishDate(Date preFinishDate) {
        this.preFinishDate = preFinishDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getBeginEndDate() {
        return beginEndDate;
    }

    public void setBeginEndDate(String beginEndDate) {
        this.beginEndDate = beginEndDate;
    }

    public Integer getFactoryCategory() {
        return factoryCategory;
    }

    public void setFactoryCategory(Integer factoryCategory) {
        this.factoryCategory = factoryCategory;
    }
}
